## ----load-package--------------------------------------------------------
suppressPackageStartupMessages(library(ForensicDocument))

## ------------------------------------------------------------------------
files = system.file("extdata", "fig-O.png", package = "ForensicDocument")
result = ExtractFourier(files = files, 
                        n.fourier = 7, 
                        n.samp = 128, 
                        verbose = FALSE, 
                        output = NULL,
                        character_pixel = 0)
result

## ----result-print, echo=FALSE, eval=TRUE---------------------------------
exp = c("typeof(result)", "length(result) == length(files)", "names(result) == files")
for(e in exp) cat(sprintf("%s : %s\n", e, eval(parse(text = e))))

## ----data-o--------------------------------------------------------------
data(characterO)

## ----lr-param------------------------------------------------------------
n.iter = 110
n.burnin = 10
nw = 50

## ------------------------------------------------------------------------
# reference & questioned
data_reference = subset(characterO$measurements[,-1], 
                        subset = (characterO$info$writer == 1))[1:23,]
data_questioned = subset(characterO$measurements[,-1], 
                         subset = (characterO$info$writer == 1))[-(1:23),]
# background
subset = characterO$info$writer != 1
data_back = subset(characterO$measurements[,-1], 
                   subset = subset)
background = TwoLevelLR_Background(data_back, 
                                   fac = as.factor(characterO$info$writer[subset]))


## ----lr-hp, eval=TRUE----------------------------------------------------
LLR = TwoLevelLR(data1 = data_reference,  
                data2 = data_questioned,
                background = background, 
                n.iter = n.iter, n.burnin = n.burnin,
                nw = nw)
LLR

## ------------------------------------------------------------------------
# reference & questioned
data_reference = subset(characterO$measurements[,-1], subset = characterO$info$writer == 1)[1:20,]
data_questioned = subset(characterO$measurements[,-1], subset = characterO$info$writer == 2)[1:20,]
subset = characterO$info$writer > 2
# background
data_back = subset(characterO$measurements[,-1], subset = subset)
background = TwoLevelLR_Background(data_back, fac = as.factor(characterO$info$writer[subset]))

## ----lr-hd, eval=TRUE----------------------------------------------------
LLR = TwoLevelLR(data1 = data_reference,  
                data2 = data_questioned,
                background = background, 
                n.iter = n.iter, n.burnin = n.burnin,
                nw = nw)
LLR

